@@ -174,9 +174,7 @@ public class ObjectToJsonConverter {
             v = pServletConfig.getInitParameter("maxObjects");
             hardMaxObjects = v != null ? Integer.parseInt(v) : 0;
         } else {
-            hardMaxDepth = 0;
-            hardMaxCollectionSize = 0;
-            hardMaxObjects = 0;
+            hardMaxDepth = hardMaxCollectionSize = hardMaxObjects = 0;
         }
     }
 
